module Node::BrowseHelperModule

  def breadcrumbs
    Pathname.new(@path).to_enum(:descend).map do |path|
      text = path == Pathname.new('/') ? node_or_share.name : spaceify(path.basename.to_s)
      url = polymorphic_path([ :browse, node_or_share ], :path => path.to_s, :sort => params['sort'])
      link_to text, url
    end.safe_join(" &#x203A; ".html_safe)
  end

  def bookmark_button
    return unless may_bookmark?
    options = {
      :id => 'create_bookmark_button',
    }
    action_button('Bookmark', options)
  end

  def create_share_button
    return unless may_create_share?
    options = {
      :id => 'create_share_button',
      'data-action' => polymorphic_path([ :browse, node_or_share ], :action => :create_share)
    }
    action_button('Create Share', options)
  end

  def create_directory_button
    return unless may_create_directory?
    options = {
     :id => 'create_directory_button'
    }
    action_button('New Folder', options)
  end

  def delete_button
    return unless may_delete?
    options = {
      :id => 'delete_button',
      'data-action' => polymorphic_path([ :browse, node_or_share ], :action => :delete)
    }
    action_button('Delete', options)
  end

  def rename_button
    return unless may_rename?
    options = {
      :id => 'rename_button'
    }
    action_button('Rename', options)
  end

  def download_button
    return unless may_download?
    options = {
      :id => 'download_button',
      :class => 'action_button_disabled',
      'data-action' => polymorphic_path([ :browse, node_or_share ], :action => :download)
    }
    action_button('Download', options)
  end

  def upload_file_button
    return unless may_upload?
    options = {
      :id => 'upload_file_button',
      :class => 'action_button_disabled',
      'data-action' => polymorphic_path([ :browse, node_or_share ], :action => :upload, :path => @path)
    }
    action_button('Upload File', options)
  end

  def upload_directory_button
    return unless may_upload?
    options = {
      :id => 'upload_directory_button',
      :class => 'action_button_disabled',
      'data-action' => polymorphic_path([ :browse, node_or_share ], :action => :upload_directory, :path => @path)
    }
    action_button('Upload Folder', options)
  end

  def more_link
    return nil unless @items.present?
    if @items.next_page
      link_to "Load more", :href => '#', :browse_url => url_for(params.merge(:page => @items.next_page)), :remote => true, :id => 'more_link', :onclick => "load_more_items()"
    elsif @items.current_page != 1
      '(No More)'
    end
  end

  def prev_link
    link_to "Prev", url_for(params.merge(:page => @items.previous_page)), :remote => true, :id => 'prev_link'
  end

  def next_link
    link_to "Next", url_for(params.merge(:page => @items.next_page)), :remote => true, :id => 'next_link'
  end

  private

  def spaceify(name)
    block = Proc.new { |match| "\u2423" * match.length }
    name
      .gsub(/^\s+|\s+$/, &block)
      .gsub(/\s{2,}/, &block)
  end

end
